@@ -107,13 +107,17 @@ fn run() -> Result<i32> {
                     print!("{}", script);
                 }
             }
-            "--argc-export" => {
+            "--argc-mangen" => {
                 let (source, args) = parse_script_args(&args[2..])?;
-                let value = argc::export(&source, &args[0])?;
-                println!("{}", serde_json::to_string_pretty(&value)?);
-            }
-            "--argc-compgen" => {
-                run_compgen(args.to_vec());
+                let outdir = args.get(1).ok_or_else(|| anyhow!("No output dir"))?;
+                let pages = argc::mangen(&source, &args[0])?;
+                let outdir = ensure_outdir(outdir).with_context(|| "Invalid output dir")?;
+                for (filename, page) in pages {
+                    let outfile = outdir.join(filename);
+                    fs::write(&outfile, page)
+                        .with_context(|| format!("Failed to write '{}'", outfile.display()))?;
+                    println!("saved {}", outfile.display());
+                }
             }
             "--argc-completions" => {
                 let shell: Shell = match args.get(2) {
@@ -123,6 +127,14 @@ fn run() -> Result<i32> {
                 let script = crate::completions::generate(shell, &args[3..]);
                 print!("{}", script);
             }
+            "--argc-compgen" => {
+                run_compgen(args.to_vec());
+            }
+            "--argc-export" => {
+                let (source, args) = parse_script_args(&args[2..])?;
+                let value = argc::export(&source, &args[0])?;
+                println!("{}", serde_json::to_string_pretty(&value)?);
+            }
             "--argc-parallel" => {
                 if args.len() <= 3 {
                     bail!("Usage: argc --argc-parallel <SCRIPT> <ARGS>...");
@@ -256,9 +268,10 @@ fn get_argc_help() -> String {
 USAGE:
     argc --argc-eval <SCRIPT> [ARGS]...             Use `eval "$(argc --argc-eval "$0" "$@")"`
     argc --argc-create [TASKS]...                   Create a boilerplate argcfile
-    argc --argc-build <SCRIPT> [OUTPATH]            Build bash script without argc dependency
+    argc --argc-build <SCRIPT> [OUTPATH]            Generate bashscript without argc dependency
+    argc --argc-mangen <SCRIPT> <OUTDIR>            Generate man pages
     argc --argc-completions <SHELL> [CMDS]...       Generate shell completion scripts
-    argc --argc-compgen <SHELL> <SCRIPT> <ARGS>...  Dynamically generating completion candidates
+    argc --argc-compgen <SHELL> <SCRIPT> <ARGS>...  Generate completion candidates
     argc --argc-export <SCRIPT>                     Export command line definitions as json
     argc --argc-parallel <SCRIPT> <ARGS>...         Execute argc functions in parallel
     argc --argc-script-path                         Print current argcfile path
@@ -295,7 +308,13 @@ fn get_argc_script_dir(path: &str) -> Option<String> {
     if candidate_script_names().iter().all(|v| !path.ends_with(v)) {
         return None;
     }
-    let script_file = fs::canonicalize(Path::new(path)).ok()?;
+    let path = Path::new(path);
+    let script_file = if path.is_absolute() {
+        path.to_path_buf()
+    } else {
+        let current_dir = env::current_dir().ok()?;
+        current_dir.join(path)
+    };
     let script_dir = script_file.parent()?;
     Some(script_dir.display().to_string())
 }
@@ -470,6 +489,22 @@ fn ensure_outpath(outpath: &str, script_name: &str) -> Result<(PathBuf, bool)> {
     }
 }
 
+fn ensure_outdir(outdir: &str) -> Result<PathBuf> {
+    match fs::metadata(outdir) {
+        Ok(metadata) => {
+            if metadata.is_dir() {
+                Ok(PathBuf::from(outdir))
+            } else {
+                bail!("Not an directory")
+            }
+        }
+        Err(_) => {
+            fs::create_dir_all(outdir)?;
+            Ok(PathBuf::from(outdir))
+        }
+    }
+}
+
 #[cfg(unix)]
 fn set_permissions<T: AsRef<Path>>(path: T) -> Result<()> {
     use std::os::unix::fs::PermissionsExt;
