@@ -118,7 +118,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                         }
                     }
                 } else if is_rest_args_positional
-                    || (cmd.no_flags_options_subcommands()
+                    || (cmd.is_empty_flags_options_subcommands()
                         && !cmd.help_flags().contains(&arg)
                         && !cmd.version_flags().contains(&arg))
                 {
@@ -392,7 +392,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
         }
         let mut output = match &self.arg_comp {
             ArgComp::FlagOrOption => {
-                let mut output = self.comp_flag_options();
+                let mut output = self.comp_flag_options(false);
                 output.extend(comp_subcomands(last_cmd, true));
                 output
             }
@@ -401,7 +401,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                 if value.len() == 2 && &self.args[self.cmd_arg_indexes[level]] == value {
                     output.extend(comp_subcomands(self.cmds[level - 1], true));
                 }
-                output.extend(self.comp_flag_options().iter().filter_map(
+                output.extend(self.comp_flag_options(true).iter().filter_map(
                     |(v, description, nospace, comp_color)| {
                         if v.len() == 2 && v != value {
                             Some((
@@ -660,7 +660,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
                         return Some(MatchError::InvalidValue(
                             level,
                             value.to_string(),
-                            param.render_value(),
+                            param.render_notation(),
                             choices.clone(),
                         ));
                     }
@@ -671,7 +671,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
             let missing_positionals: Vec<_> = last_cmd.positional_params[positional_values_len..]
                 .iter()
                 .filter(|param| param.required())
-                .map(|v| v.render_value())
+                .map(|v| v.render_notation())
                 .collect();
             if !missing_positionals.is_empty() {
                 return Some(MatchError::MissingRequiredArguments(
@@ -858,7 +858,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
         (message, exit)
     }
 
-    fn comp_flag_options(&self) -> Vec<CompItem> {
+    fn comp_flag_options(&self, combine: bool) -> Vec<CompItem> {
         let mut output = vec![];
         let level = self.cmds.len() - 1;
         let last_cmd = self.last_cmd();
@@ -867,7 +867,12 @@ impl<'a, 'b> Matcher<'a, 'b> {
             .filter_map(|v| v.2)
             .collect();
         let last = self.args.last().map(|v| v.as_str()).unwrap_or_default();
-        for param in last_cmd.flag_option_params.iter() {
+        let params = if combine {
+            last_cmd.flag_option_params.iter().collect()
+        } else {
+            last_cmd.all_flag_options()
+        };
+        for param in params.iter() {
             let mut exist = args.contains(param.id());
             if !last.is_empty() && param.is_match(last) {
                 exist = false;
