@@ -129,7 +129,7 @@ cmda() { :; }
 # @cmd
 cmdb() { :; }
 # @cmd
-cmdbc() { :; }
+cmdc() { :; }
 "###;
 
     snapshot_compgen!(
@@ -944,13 +944,51 @@ _choice_fn() {
     echo "__argc_filter=${ARGC_CWORD#*=}"
     echo foo
     echo bar
-    :;
 }
 "#;
 
     snapshot_compgen_shells!(script, ["prog", "v='"]);
 }
 
+#[test]
+fn break_chars_bash() {
+    let script = r#"
+# @arg args[`_choice_fn`]
+_choice_fn() {
+    echo "a1:b1"
+    echo "a1:b2"
+    echo "a1@b1"
+    echo "a1@b2"
+    echo "a1=b1"
+    echo "a1=b2"
+    echo "a1 b1"
+    echo "a1 b2"
+}
+"#;
+    snapshot_compgen!(
+        script,
+        [
+            vec!["prog", "a1:b"],
+            vec!["prog", "a1@b"],
+            vec!["prog", "a1=b"],
+            vec!["prog", "a1 b"],
+        ],
+        argc::Shell::Bash
+    );
+}
+
+#[test]
+fn break_chars_powershell() {
+    let script = r#"
+# @arg args[`_choice_fn`]
+_choice_fn() {
+    echo abc,def
+    echo abc,ghi
+}
+"#;
+    snapshot_compgen!(script, [vec!["prog", "abc,"],], argc::Shell::Powershell);
+}
+
 #[test]
 fn color() {
     let script = r#"
