@@ -36,10 +36,13 @@ fn help_version_shadow() {
 #[test]
 fn help_version_exist() {
     let script = r###"
+# @describe Test argc
+# @version    1.0.0
+
 # @flag -h --help
 # @flag -V --version
 "###;
-    snapshot_multi!(script, [vec!["prog", "-h"]]);
+    snapshot_multi!(script, [vec!["prog", "-h"], vec!["prog", "-V"]]);
 }
 
 #[test]
@@ -52,6 +55,18 @@ fn help_notations() {
     snapshot_multi!(script, [vec!["prog", "-h"]]);
 }
 
+#[test]
+fn version() {
+    let script = r###"
+# @cmd
+cmd() { :; }
+"###;
+    snapshot_multi!(
+        script,
+        [vec!["prog", "--version"], vec!["prog", "cmd", "--version"]]
+    );
+}
+
 #[test]
 fn arg_help_subcmd() {
     snapshot!(SCRIPT_ARGS, &["prog", "help", "cmd_required_multi_arg"]);
@@ -239,28 +254,41 @@ _choice_fn() {
     snapshot_multi!(script, [vec!["prog", "cmd", "a\\b", "a\\b"],]);
 }
 
+#[test]
+fn delimiter() {
+    let script = r###"
+# @cmd
+# @option --oa*,[`_choice_fn`]
+# @arg val*,[`_choice_fn`]
+cmd() { :; }
+
+_choice_fn() {
+    echo -e "abc\ndef\nijk"
+}
+"###;
+    snapshot_multi!(
+        script,
+        [
+            vec!["prog", "cmd", "--oa", "abc,def"],
+            vec!["prog", "cmd", "abc,def"]
+        ]
+    );
+}
+
 #[test]
 fn cmd_name_sanitize() {
     let script = r###"
 # @cmd
-cat_() {
-    echo run cat_
-}
+cat_() { :; }
 
 # @cmd
-do_() {
-    echo run do_
-}
+do_() { :; }
 
 # @cmd
-do_::foo() {
-    echo run do_::foo
-}
+do_::foo() { :; }
 
 # @cmd
-do_::bar() {
-    echo run do_::bar
-}
+do_::bar() { :; }
 "###;
     snapshot_multi!(
         script,
